//------------------------------------------------------------------------------
// File: PushSource.H
//
// Desc: DirectShow sample code - In-memory push mode source filter
//
// Copyright (c) Microsoft Corporation.  All rights reserved.
//------------------------------------------------------------------------------


#include <strsafe.h>

// UNITS = 10 ^ 7  
// UNITS / 25 = 25 fps;
const REFERENCE_TIME FPS_25 = UNITS / 25;

const REFERENCE_TIME rtDefaultFrameLength = FPS_25;

// Filter name strings
#define g_wszPushTeletext    L"PushSource Teletext Filter"

extern char g_SourceFilePath[];

/**********************************************
 *
 *  Class declarations
 *
 **********************************************/

class CPushPinTeletext : public CSourceStream
{
protected:
	HANDLE m_hFile;			// Handle returned from CreateFile
	DWORD m_nDataSize;		// size of one teletext data
	DWORD m_iFrameNumber;	// next frame number
	const REFERENCE_TIME m_rtFrameLength;

    CCritSec m_cSharedState;            // Protects our internal state

public:

	CPushPinTeletext(HRESULT *phr, CSource *pFilter);
    ~CPushPinTeletext();

    // Override the version that offers exactly one media type
    HRESULT GetMediaType(CMediaType *pMediaType);
    HRESULT DecideBufferSize(IMemAllocator *pAlloc, ALLOCATOR_PROPERTIES *pRequest);
    HRESULT FillBuffer(IMediaSample *pSample);
    
    // Quality control
	// Not implemented because we aren't going in real time.
	// If the file-writing filter slows the graph down, we just do nothing, which means
	// wait until we're unblocked. No frames are ever dropped.
    STDMETHODIMP Notify(IBaseFilter *pSelf, Quality q)
    {
        return E_FAIL;
    }

};



class CPushSourceTeletext : public CSource
{

private:
    // Constructor is private because you have to use CreateInstance
	CPushSourceTeletext(IUnknown *pUnk, HRESULT *phr);
    ~CPushSourceTeletext();

    CPushPinTeletext *m_pPin;

public:
    static CUnknown * WINAPI CreateInstance(IUnknown *pUnk, HRESULT *phr);  

};


