//------------------------------------------------------------------------------
// File: Setup.cpp
//
// Desc: DirectShow sample code - implementation of PushSource sample filters
//
// Copyright (c)  Microsoft Corporation.  All rights reserved.
//------------------------------------------------------------------------------

#include <streams.h>
#include <initguid.h>

#include "PushGuids.h"
#include "PushSource.h"

// Note: It is better to register no media types than to register a partial 
// media type (subtype == GUID_NULL) because that can slow down intelligent connect 
// for everyone else.

// For a specialized source filter like this, it is best to leave out the 
// AMOVIESETUP_FILTER altogether, so that the filter is not available for 
// intelligent connect. Instead, use the CLSID to create the filter or just 
// use 'new' in your application.


// Filter setup data
//
const AMOVIESETUP_MEDIATYPE sudOpPinTypes =
{
	&MEDIATYPE_Stream,			// Major type
	&MEDIATYPE_DVB_TELETEXT		// Minor type
};


const AMOVIESETUP_PIN sudOutputPinTeletext = 
{
    L"Output",      // Obsolete, not used.
    FALSE,          // Is this pin rendered?
    TRUE,           // Is it an output pin?
    FALSE,          // Can the filter create zero instances?
    FALSE,          // Does the filter create multiple instances?
    &CLSID_NULL,    // Obsolete.
    NULL,           // Obsolete.
    1,              // Number of media types.
    &sudOpPinTypes  // Pointer to media types.
};

const AMOVIESETUP_FILTER sudPushSourceTeletext =
{
    &CLSID_PushSourceTeletext,	// Filter CLSID
    g_wszPushTeletext,			// String name
    MERIT_DO_NOT_USE,			// Filter merit
    1,							// Number pins
    &sudOutputPinTeletext		// Pin details
};



// List of class IDs and creator functions for the class factory. This
// provides the link between the OLE entry point in the DLL and an object
// being created. The class factory will call the static CreateInstance.
// We provide a set of filters in this one DLL.

CFactoryTemplate g_Templates[1] = 
{
    { 
      g_wszPushTeletext,					// Name
      &CLSID_PushSourceTeletext,			// CLSID
      CPushSourceTeletext::CreateInstance,	// Method to create an instance of MyComponent
      NULL,									// Initialization function
      &sudPushSourceTeletext				// Set-up information (for filters)
    },
};
int g_cTemplates = sizeof(g_Templates) / sizeof(g_Templates[0]);    



////////////////////////////////////////////////////////////////////////
//
// Exported entry points for registration and unregistration 
// (in this case they only call through to default implementations).
//
////////////////////////////////////////////////////////////////////////

char g_SourceFilePath[MAX_PATH] = { 0 };

STDAPI DllRegisterServer()
{
    return AMovieDllRegisterServer2( TRUE );
}

STDAPI DllUnregisterServer()
{
    return AMovieDllRegisterServer2( FALSE );
}

//
// DllEntryPoint
//
extern "C" BOOL WINAPI DllEntryPoint(HINSTANCE, ULONG, LPVOID);

BOOL APIENTRY DllMain(HANDLE hModule, 
                      DWORD  dwReason, 
                      LPVOID lpReserved)
{
	GetModuleFileNameA((HMODULE)hModule, g_SourceFilePath, MAX_PATH);
	int pos=0;
	for (int i = 0; i < MAX_PATH; i++) {
		if (0 == g_SourceFilePath[i])  break;
		if ('\\' == g_SourceFilePath[i])  pos = i + 1;
	}
	strcpy_s(&g_SourceFilePath[pos], MAX_PATH - pos, "source.ttdata");
	return DllEntryPoint((HINSTANCE)(hModule), dwReason, lpReserved);
}

